# grassp - Graph-based analysis of subcellular proteomics data

```{include} ../../README.md
```

## Contents
```{toctree}
:hidden: true
:maxdepth: 4

installation
tutorials/index
api/index
contributing
contributors
references
```
